@@ -9,8 +9,9 @@ get.data <- function(path.in, path.out, file, set = "",
   graphics.off()
   transf <- logtrans # default
   if (is.null(data)) { # checking external data
-    ext.csv <- c("CSV", "csv")
-    ext.xls <- c("XLS", "xls", "XLSX", "xlsx")
+    if (!missing(ext)) ext <- tolower(ext) # case-insensitive
+    ext.csv <- "csv"
+    ext.xls <- c("xls", "xlsx")
     if (missing(file))
       stop("Argument 'file' must be given.")
     if (is.numeric(file))
@@ -81,13 +82,14 @@ get.data <- function(path.in, path.out, file, set = "",
     if (ext %in% ext.xls) { # read from Excel to the data frame
       datawithdescr <- as.data.frame(read_excel(path=full.name, sheet=set,
                                                 na=c("NA", "ND", ".", "", "Missing"),
-                                                skip=0, col_names=FALSE))
+                                                skip=0, col_names=FALSE, .name_repair="minimal"))
     } else {
-      datawithdescr <- read.csv(file=full.name, sep=sep, dec=dec, quote="", header=FALSE,
-                                strip.white=TRUE, na.strings=c("NA", "ND", ".", "", "Missing"),
+      datawithdescr <- read.csv(file=full.name, sep=sep, dec=dec, quote="'\"",
+                                header=FALSE, strip.white=TRUE,
+                                na.strings=c("NA", "ND", ".", "", "Missing"),
                                 stringsAsFactors=FALSE)
     }
-    namesvector = c("subject", "period", "sequence", "treatment")
+    namesvector <- c("subject", "period", "sequence", "treatment")
     # Looking for a row with namesvector, summing all its members and
     # if all are there, mark as TRUE
     Nnamesdf <- c(t(apply(datawithdescr, 1, function(row, table) {
@@ -120,10 +122,12 @@ get.data <- function(path.in, path.out, file, set = "",
     # Convert eventual mixed or upper case variable names to lower case
     facs  <- which(!names(data) %in% c("PK", "logPK")) # will be factors later
     names(data)[facs] <- tolower(names(data)[facs])
+    # if the file contains a first column named NA (imported row.name):
+    if (typeof(data[[1]]) == "integer") data <- data[, -1] # remove it
     # from demo(error.catching)
     tryCatch.W.E <- function(expr) {
       W <- NULL
-      w.handler <- function(w){ # warning handler
+      w.handler <- function(w) { # warning handler
         W <<- w
         invokeRestart("muffleWarning")
       }
